==> sqldeveloper-4.0.2.15.21-no-jre.zip: ilog/views/faces/resources/diagrammer.js <==
/*
 *
 * IBM Confidential 
 * OCO Source Materials 
 * 5724-Y35 
 * (C) Copyright IBM Corp. 1996, 2009 
 * The source code for this program is not published or otherwise 
 * divested of its trade secrets, irrespective of what has 
 * been deposited with the U.S. Copyright Office. 
 *
 */

if (typeof(IlvConstants) == "undefined" || typeof(IlvConstants.DiagrammerBundleDefined) == "undefined") {
IlvDiagrammerViewProxyUtil=function(){
};
IlvDiagrammerViewProxyUtil.setCreateInteractor=function(_1,_2,_3,_4){
if(!this.editable){
return;
}
if(!this.makeObjectInteractor){
throw new Error("should not happen, is your diagrammer view editable?");
}
this.makeObjectInteractor.setAdditionalParameters(_1);
this.makeObjectInteractor.setProperties(_3);
this.makeObjectInteractor.setLinkMode(_4);
if(_2){
if(this.getInteractor()!=this.makeObjectInteractor){
this.makeObjectInteractor.setOneShot(this.getInteractor());
}
}else{
this.makeObjectInteractor.setOneShot(null);
}
this.setInteractor(this.makeObjectInteractor);
};
IlvDiagrammerViewProxyUtil.setStyleSheets=function(_5,_6){
this.css=_5;
var _7=this.getObject();
_7.setAdditionalParameters("css",this.css);
if(_6){
_7.updateImage();
}
this.notify("StyleSheets");
};
IlvDiagrammerViewProxyUtil.setDataSourceId=function(_8,_9){
this.dataSourceId=_8;
var _a=this.getObject();
_a.setAdditionalParameters("facesDataSourceId",this.dataSourceId);
_a.setAdditionalParameters("slc",this.staticLayersCount);
if(_9){
_a.updateAll(false,true);
}
this.notify("DataSourceId");
};
IlvDiagrammerViewProxyUtil.setProject=function(_b,_c,_d){
this.project=_b;
var _e=this.getObject();
_e.setAdditionalParameters("project",this.project);
_e.setAdditionalParameters("slc",this.staticLayersCount);
if(_c){
_e.updateAll(_d,true);
}
this.notify("Project");
};
IlvDiagrammerViewProxyUtil.setMakeObjectInteractor=function(_f){
this.makeObjectInteractor=_f;
};
IlvDiagrammerViewProxyUtil.removeAdditionalParameters=function(_10){
_10.removeAdditionalParameter("project");
_10.removeAdditionalParameter("facesDataSourceId");
_10.removeAdditionalParameter("css");
_10.removeAdditionalParameter("xml");
_10.removeAdditionalParameter("slc");
};
IlvDiagrammerViewProxyUtil.createObject=function(_11,_12){
var _13=this.getObject();
if(_12){
var buf=[];
for(var _15 in _12){
buf.push(_15);
buf.push("\""+_12[_15]+"\"");
}
_13.setAdditionalParameters("properties",buf.join(","));
}
var _16=_13.getSelectionManager().additionalParams;
var _17=_16?_16.length:0;
for(var i=0;i<_17;i+=2){
_13.setAdditionalParameters(_16[i],_16[i+1]);
}
_13.performAction("createObject",_11,"capabilities");
if(_12){
_13.removeAdditionalParameter("properties");
}
for(i=0;i<_17;i+=2){
_13.removeAdditionalParameter(_16[i]);
}
};
IlvConstants.DiagrammerBundleDefined=true;
IlvDiagrammerViewProxy=function(_1,_2,_3,_4,_5){
this.superConstructor(_1,_2,_3,_4);
this.setServletClass("ilog.views.diagrammer.faces.dhtml.servlet.IlvFacesDiagrammerServlet");
var _6=this.getObject();
_6.setAdditionalParameters("facesComponentId",_1);
_6.addImageOnLoadListener(IlvDiagrammerViewProxy.imageLoaded);
_6.addCapabilitiesOnLoadListener(IlvDiagrammerViewProxy.capabilitiesLoaded);
this.editable=_5;
};
IlvDiagrammerViewProxy.prototype=new IlvFacesViewProxy();
IlvDiagrammerViewProxy.prototype.setClassName("IlvDiagrammerViewProxy");
IlvDiagrammerViewProxy.prototype.afterLayoutHandler=function(_7){
this.superInvoke("afterLayoutHandler");
var _8=this.getObject();
_8.setAdditionalParameters("componentWidth",_8.getWidth());
_8.setAdditionalParameters("componentHeight",_8.getHeight());
};
IlvDiagrammerViewProxy.prototype.getSelectionManager=function(){
return this.getObject().getSelectionManager();
};
IlvDiagrammerViewProxy.prototype.getProject=function(){
return this.project;
};
IlvDiagrammerViewProxy.prototype.setProject=function(_9,_a,_b){
IlvDiagrammerViewProxyUtil.setProject.call(this,_9,_a,_b);
};
IlvDiagrammerViewProxy.prototype.setDataSourceId=function(_c,_d){
IlvDiagrammerViewProxyUtil.setDataSourceId.call(this,_c,_d);
};
IlvDiagrammerViewProxy.prototype.getDataSourceId=function(){
return this.dataSourceId;
};
IlvDiagrammerViewProxy.prototype.setStyleSheets=function(_e,_f){
IlvDiagrammerViewProxyUtil.setStyleSheets.call(this,_e,_f);
};
IlvDiagrammerViewProxy.prototype.getStyleSheets=function(){
return this.css;
};
IlvDiagrammerViewProxy.prototype.setCreateNodeInteractor=function(tag,_11,_12){
IlvDiagrammerViewProxyUtil.setCreateInteractor.call(this,tag,_11,_12,false);
};
IlvDiagrammerViewProxy.prototype.setCreateLinkInteractor=function(tag,_14,_15){
IlvDiagrammerViewProxyUtil.setCreateInteractor.call(this,tag,_14,_15,true);
};
IlvDiagrammerViewProxy.capabilitiesLoaded=function(_16){
IlvDiagrammerViewProxyUtil.removeAdditionalParameters(_16);
};
IlvDiagrammerViewProxy.imageLoaded=function(_17){
IlvDiagrammerViewProxyUtil.removeAdditionalParameters(_17);
};
IlvDiagrammerViewProxy.prototype.performJSFAction=function(mb,_19,_1a,_1b){
var p=_19?[mb].concat(_19):[mb];
this.performAction("jsfAction",p,_1a,_1b);
};
IlvDiagrammerViewProxy.prototype.createNode=function(x,y,tag,_20){
this.createObject([x,y,"true",tag],_20);
};
IlvDiagrammerViewProxy.prototype.createLink=function(_21,_22,_23,_24,tag,_26){
this.createObject([_21,_22,"false",tag,_23,_24],_26);
};
IlvDiagrammerViewProxy.prototype.createObject=IlvDiagrammerViewProxyUtil.createObject;
IlvDiagrammerViewProxy.prototype.setMakeObjectInteractor=IlvDiagrammerViewProxyUtil.setMakeObjectInteractor;
IlvDiagrammerTiledViewProxy=function(_1,_2,_3,_4,_5,_6){
this.superConstructor(_1,_2,_3,_4,_5);
if(_1){
this.setServletClass("ilog.views.diagrammer.faces.dhtml.servlet.IlvFacesDiagrammerServlet");
var _7=this.getObject();
_7.setAdditionalParameters("facesComponentId",_1);
_7.addImageOnLoadListener(IlvDiagrammerTiledViewProxy.imageLoaded);
_7.addCapabilitiesOnLoadListener(IlvDiagrammerTiledViewProxy.capabilitiesLoaded);
}
this.editable=_6;
};
IlvDiagrammerTiledViewProxy.prototype=new IlvFacesTiledViewProxy();
IlvDiagrammerTiledViewProxy.prototype.setClassName("IlvDiagrammerTiledViewProxy");
IlvDiagrammerTiledViewProxy.prototype.afterLayoutHandler=function(_8){
this.superInvoke("afterLayoutHandler");
var _9=this.getObject();
_9.setAdditionalParameters("componentWidth",_9.getWidth());
_9.setAdditionalParameters("componentHeight",_9.getHeight());
};
IlvDiagrammerTiledViewProxy.prototype.getSelectionManager=function(){
return this.getObject().getSelectionManager();
};
IlvDiagrammerTiledViewProxy.prototype.getProject=function(){
return this.project;
};
IlvDiagrammerTiledViewProxy.prototype.setProject=function(_a,_b,_c){
IlvDiagrammerViewProxyUtil.setProject.call(this,_a,_b,_c);
};
IlvDiagrammerTiledViewProxy.prototype.setDataSourceId=function(_d,_e){
IlvDiagrammerViewProxyUtil.setDataSourceId.call(this,_d,_e);
};
IlvDiagrammerTiledViewProxy.prototype.getDataSourceId=function(){
return this.dataSourceId;
};
IlvDiagrammerTiledViewProxy.prototype.setStyleSheets=function(_f,_10){
IlvDiagrammerViewProxyUtil.setStyleSheets.call(this,_f,_10);
};
IlvDiagrammerTiledViewProxy.prototype.getStyleSheets=function(){
return this.css;
};
IlvDiagrammerTiledViewProxy.prototype.setCreateNodeInteractor=function(tag,_12,_13){
IlvDiagrammerViewProxyUtil.setCreateInteractor.call(this,tag,_12,_13,false);
};
IlvDiagrammerTiledViewProxy.prototype.setCreateLinkInteractor=function(tag,_15,_16){
IlvDiagrammerViewProxyUtil.setCreateInteractor.call(this,tag,_15,_16,true);
};
IlvDiagrammerTiledViewProxy.prototype.createNode=function(x,y,tag,_1a){
this.createObject([x,y,"true",tag],_1a);
};
IlvDiagrammerTiledViewProxy.prototype.createLink=function(_1b,_1c,_1d,_1e,tag,_20){
this.createObject([_1b,_1c,"false",tag,_1d,_1e],_20);
};
IlvDiagrammerTiledViewProxy.prototype.createObject=IlvDiagrammerViewProxyUtil.createObject;
IlvDiagrammerTiledViewProxy.capabilitiesLoaded=function(_21){
IlvDiagrammerViewProxyUtil.removeAdditionalParameters(_21);
};
IlvDiagrammerTiledViewProxy.imageLoaded=function(_22){
IlvDiagrammerViewProxyUtil.removeAdditionalParameters(_22);
};
IlvDiagrammerTiledViewProxy.prototype.setMakeObjectInteractor=IlvDiagrammerViewProxyUtil.setMakeObjectInteractor;
IlvDiagrammerMakeObjectInteractorProxy=function(_1){
this.superConstructor(_1);
this.setObject(new IlvMakeObjectInteractor());
};
IlvDiagrammerMakeObjectInteractorProxy.prototype=new IlvInteractorProxy();
IlvDiagrammerMakeObjectInteractorProxy.prototype.setClassName("IlvDiagrammerMakeObjectInteractorProxy");
IlvDiagrammerMakeObjectInteractorProxy.prototype.setLinkMode=function(_2){
this.getObject().setLinkMode(_2);
this.notify("LinkMode");
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.isLinkMode=function(_3){
return this.getObject().getLinkMode();
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.setAdditionalParameters=function(_4){
this.getObject().setAdditionalParameters(_4);
this.notify("AdditionalParameters");
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.getAdditionalParameters=function(){
return this.getObject().additionalParams;
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.setProperties=function(_5){
this.getObject().setProperties(_5);
this.notify("Properties");
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.getProperties=function(){
return this.getObject().properties;
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.setOneShot=function(_6){
this.oldInteractor=_6;
if(this.oldInteractor){
if(!this.popInteractorCallback){
this.popInteractorCallback=function(){
this.getView().JSFRef.setInteractor(this.JSFRef.oldInteractor);
};
}
this.getObject().setOnCompleted(this.popInteractorCallback);
}else{
this.oldInteractor=null;
this.getObject().setOnCompleted(null);
}
this.notify("OneShotId");
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.getOneShotId=function(){
if(this.oldInteractor){
return this.oldInteractor.getAbsoluteId();
}else{
return null;
}
};
IlvDiagrammerSelectionManagerProxy=function(_1,_2,_3){
this.superConstructor(_1,_2.getSelectionManager(),_3);
};
IlvDiagrammerSelectionManagerProxy.prototype=new IlvFacesSelectionManagerProxy();
IlvDiagrammerSelectionManagerProxy.prototype.setClassName("IlvDiagrammerSelectionManagerProxy");
IlvFacesDiagrammerSelectInteractor=function(){
this.superConstructor();
};
IlvFacesDiagrammerSelectInteractor.prototype=new IlvSelectInteractor();
IlvFacesDiagrammerSelectInteractor.prototype.setClassName("IlvFacesDiagrammerSelectInteractor");
IlvFacesDiagrammerSelectInteractor.prototype.setView=function(_1){
if(_1==null){
this.JSFRef.desinstallInteractor(this.view.getSelectionManager());
}else{
this.JSFRef.setupSelectionManager(_1.getSelectionManager());
}
};
IlvFacesDiagrammerSelectInteractor.prototype.keyDown=function(e){
if(this.view!=null){
var _3=this.view.getSelectionManager();
if(e.keyCode==27){
if(_3!=null&&_3.isDragging()){
_3.abortDragging(e);
}
}else{
if(this.JSFRef.isDeletionAllowed()&&e.keyCode==46){
if(_3!=null&&!_3.isDragging()){
_3.deleteSelection();
}
}else{
if(e.keyCode==65&&e.ctrlKey){
var _3=this.view.getSelectionManager();
if(_3!=null){
_3.selectAll();
if(e.preventDefault){
e.preventDefault();
return false;
}
}
}
}
}
}
};
IlvDiagrammerSelectInteractorProxy=function(_4,_5){
this.superConstructor(_4,_5);
this.setObject(new IlvFacesDiagrammerSelectInteractor());
this.deletionAllowed=false;
};
IlvDiagrammerSelectInteractorProxy.prototype=new IlvFacesSelectInteractorProxy();
IlvDiagrammerSelectInteractorProxy.prototype.setClassName("IlvDiagrammerSelectInteractorProxy");
IlvDiagrammerSelectInteractorProxy.prototype.setDeletionAllowed=function(_6){
this.deletionAllowed=_6;
this.notify("DeletionAllowed");
};
IlvDiagrammerSelectInteractorProxy.prototype.isDeletionAllowed=function(){
return this.deletionAllowed;
};
}

==> sqldeveloper-23.1.0.097.1607-no-jre.zip: ilog/views/faces/resources/diagrammer.js <==
/*
 * Licensed Materials - Property of Rogue Wave Software, Inc. 
 * © Copyright Rogue Wave Software, Inc. 2014, 2015 
 * © Copyright IBM Corp. 2009, 2014
 * © Copyright ILOG 1996, 2009
 * All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * The Software and Documentation were developed at private expense and
 * are "Commercial Items" as that term is defined at 48 CFR 2.101,
 * consisting of "Commercial Computer Software" and
 * "Commercial Computer Software Documentation", as such terms are
 * used in 48 CFR 12.212 or 48 CFR 227.7202-1 through 227.7202-4,
 * as applicable.
 */

if (typeof(IlvConstants) == "undefined" || typeof(IlvConstants.DiagrammerBundleDefined) == "undefined") {
IlvDiagrammerViewProxyUtil=function(){
};
IlvDiagrammerViewProxyUtil.setCreateInteractor=function(_1,_2,_3,_4){
if(!this.editable){
return;
}
if(!this.makeObjectInteractor){
throw new Error(jviews.messages.IlvDiagrammerViewProxyUtil.isEditable);
}
this.makeObjectInteractor.setAdditionalParameters(_1);
this.makeObjectInteractor.setProperties(_3);
this.makeObjectInteractor.setLinkMode(_4);
if(_2){
if(this.getInteractor()!=this.makeObjectInteractor){
this.makeObjectInteractor.setOneShot(this.getInteractor());
}
}else{
this.makeObjectInteractor.setOneShot(null);
}
this.setInteractor(this.makeObjectInteractor);
};
IlvDiagrammerViewProxyUtil.setStyleSheets=function(_5,_6){
this.css=_5;
var _7=this.getObject();
_7.setAdditionalParameters("css",this.css);
if(_6){
_7.updateImage();
}
this.notify("StyleSheets");
};
IlvDiagrammerViewProxyUtil.setDataSourceId=function(_8,_9){
this.dataSourceId=_8;
var _a=this.getObject();
_a.setAdditionalParameters("facesDataSourceId",this.dataSourceId);
_a.setAdditionalParameters("slc",this.staticLayersCount);
if(_9){
_a.updateAll(false,true);
}
this.notify("DataSourceId");
};
IlvDiagrammerViewProxyUtil.setProject=function(_b,_c,_d){
this.project=_b;
var _e=this.getObject();
_e.setAdditionalParameters("project",this.project);
_e.setAdditionalParameters("slc",this.staticLayersCount);
if(_c){
_e.updateAll(_d,true);
}
this.notify("Project");
};
IlvDiagrammerViewProxyUtil.setMakeObjectInteractor=function(_f){
this.makeObjectInteractor=_f;
};
IlvDiagrammerViewProxyUtil.removeAdditionalParameters=function(_10){
_10.removeAdditionalParameter("project");
_10.removeAdditionalParameter("facesDataSourceId");
_10.removeAdditionalParameter("css");
_10.removeAdditionalParameter("xml");
_10.removeAdditionalParameter("slc");
};
IlvDiagrammerViewProxyUtil.createObject=function(_11,_12){
var _13=this.getObject();
if(_12){
var buf=[];
for(var _15 in _12){
buf.push(IlvUtil.encodeStringAttribute(_15));
var _16=_12[_15];
_16=IlvUtil.encodeStringAttribute(_16);
buf.push("\""+_16+"\"");
}
_13.setAdditionalParameters("properties",buf.join(","));
}
var _17=_13.getSelectionManager().additionalParams;
var _18=0;
var _19=-1;
if(_17){
_19=IlvUtil.indexOf(_17,IlvPageId.pageIdKey);
_18=_17.length;
}
for(var i=0;i<_18;i+=2){
_13.setAdditionalParameters(_17[i],_17[i+1]);
}
_13.performAction("createObject",_11,"capabilities");
if(_12){
_13.removeAdditionalParameter("properties");
}
for(i=0;i<_18;i+=2){
if(i!=_19){
_13.removeAdditionalParameter(_17[i]);
}
}
};
IlvConstants.DiagrammerBundleDefined=true;
IlvDiagrammerViewProxy=function(_1,_2,_3,_4,_5){
this.superConstructor(_1,_2,_3,_4);
this.setServletClass("ilog.views.diagrammer.faces.dhtml.servlet.IlvFacesDiagrammerServlet");
var _6=this.getObject();
_6.setAdditionalParameters("facesComponentId",_1);
_6.setAdditionalParameters("locale",IlvConstants.locale);
_6.addImageOnLoadListener(IlvDiagrammerViewProxy.imageLoaded);
_6.addCapabilitiesOnLoadListener(IlvDiagrammerViewProxy.capabilitiesLoaded);
this.editable=_5;
};
IlvDiagrammerViewProxy.prototype=new IlvFacesViewProxy();
IlvDiagrammerViewProxy.prototype.setClassName("IlvDiagrammerViewProxy");
IlvDiagrammerViewProxy.prototype.afterLayoutHandler=function(_7){
this.superInvoke("afterLayoutHandler");
var _8=this.getObject();
_8.setAdditionalParameters("componentWidth",_8.getWidth());
_8.setAdditionalParameters("componentHeight",_8.getHeight());
};
IlvDiagrammerViewProxy.prototype.getSelectionManager=function(){
return this.getObject().getSelectionManager();
};
IlvDiagrammerViewProxy.prototype.getProject=function(){
return this.project;
};
IlvDiagrammerViewProxy.prototype.setProject=function(_9,_a,_b){
IlvDiagrammerViewProxyUtil.setProject.call(this,_9,_a,_b);
};
IlvDiagrammerViewProxy.prototype.setDataSourceId=function(_c,_d){
IlvDiagrammerViewProxyUtil.setDataSourceId.call(this,_c,_d);
};
IlvDiagrammerViewProxy.prototype.getDataSourceId=function(){
return this.dataSourceId;
};
IlvDiagrammerViewProxy.prototype.setStyleSheets=function(_e,_f){
IlvDiagrammerViewProxyUtil.setStyleSheets.call(this,_e,_f);
};
IlvDiagrammerViewProxy.prototype.getStyleSheets=function(){
return this.css;
};
IlvDiagrammerViewProxy.prototype.setCreateNodeInteractor=function(tag,_11,_12){
IlvDiagrammerViewProxyUtil.setCreateInteractor.call(this,tag,_11,_12,false);
};
IlvDiagrammerViewProxy.prototype.setCreateLinkInteractor=function(tag,_14,_15){
IlvDiagrammerViewProxyUtil.setCreateInteractor.call(this,tag,_14,_15,true);
};
IlvDiagrammerViewProxy.capabilitiesLoaded=function(_16){
IlvDiagrammerViewProxyUtil.removeAdditionalParameters(_16);
};
IlvDiagrammerViewProxy.imageLoaded=function(_17){
IlvDiagrammerViewProxyUtil.removeAdditionalParameters(_17);
};
IlvDiagrammerViewProxy.prototype.performJSFAction=function(mb,_19,_1a,_1b){
var p=_19?[mb].concat(_19):[mb];
this.performAction("jsfAction",p,_1a,_1b);
};
IlvDiagrammerViewProxy.prototype.createNode=function(x,y,tag,_20){
this.createObject([x,y,"true",tag],_20);
};
IlvDiagrammerViewProxy.prototype.createLink=function(_21,_22,_23,_24,tag,_26){
this.createObject([_21,_22,"false",tag,_23,_24],_26);
};
IlvDiagrammerViewProxy.prototype.createObject=IlvDiagrammerViewProxyUtil.createObject;
IlvDiagrammerViewProxy.prototype.setMakeObjectInteractor=IlvDiagrammerViewProxyUtil.setMakeObjectInteractor;
IlvDiagrammerTiledViewProxy=function(_1,_2,_3,_4,_5,_6){
this.superConstructor(_1,_2,_3,_4,_5);
if(_1){
this.setServletClass("ilog.views.diagrammer.faces.dhtml.servlet.IlvFacesDiagrammerServlet");
var _7=this.getObject();
_7.setAdditionalParameters("facesComponentId",_1);
_7.setAdditionalParameters("locale",IlvConstants.locale);
_7.addImageOnLoadListener(IlvDiagrammerTiledViewProxy.imageLoaded);
_7.addCapabilitiesOnLoadListener(IlvDiagrammerTiledViewProxy.capabilitiesLoaded);
}
this.editable=_6;
};
IlvDiagrammerTiledViewProxy.prototype=new IlvFacesTiledViewProxy();
IlvDiagrammerTiledViewProxy.prototype.setClassName("IlvDiagrammerTiledViewProxy");
IlvDiagrammerTiledViewProxy.prototype.afterLayoutHandler=function(_8){
this.superInvoke("afterLayoutHandler");
var _9=this.getObject();
_9.setAdditionalParameters("componentWidth",_9.getWidth());
_9.setAdditionalParameters("componentHeight",_9.getHeight());
};
IlvDiagrammerTiledViewProxy.prototype.getSelectionManager=function(){
return this.getObject().getSelectionManager();
};
IlvDiagrammerTiledViewProxy.prototype.getProject=function(){
return this.project;
};
IlvDiagrammerTiledViewProxy.prototype.setProject=function(_a,_b,_c){
IlvDiagrammerViewProxyUtil.setProject.call(this,_a,_b,_c);
};
IlvDiagrammerTiledViewProxy.prototype.setDataSourceId=function(_d,_e){
IlvDiagrammerViewProxyUtil.setDataSourceId.call(this,_d,_e);
};
IlvDiagrammerTiledViewProxy.prototype.getDataSourceId=function(){
return this.dataSourceId;
};
IlvDiagrammerTiledViewProxy.prototype.setStyleSheets=function(_f,_10){
IlvDiagrammerViewProxyUtil.setStyleSheets.call(this,_f,_10);
};
IlvDiagrammerTiledViewProxy.prototype.getStyleSheets=function(){
return this.css;
};
IlvDiagrammerTiledViewProxy.prototype.setCreateNodeInteractor=function(tag,_12,_13){
IlvDiagrammerViewProxyUtil.setCreateInteractor.call(this,tag,_12,_13,false);
};
IlvDiagrammerTiledViewProxy.prototype.setCreateLinkInteractor=function(tag,_15,_16){
IlvDiagrammerViewProxyUtil.setCreateInteractor.call(this,tag,_15,_16,true);
};
IlvDiagrammerTiledViewProxy.prototype.createNode=function(x,y,tag,_1a){
this.createObject([x,y,"true",tag],_1a);
};
IlvDiagrammerTiledViewProxy.prototype.createLink=function(_1b,_1c,_1d,_1e,tag,_20){
this.createObject([_1b,_1c,"false",tag,_1d,_1e],_20);
};
IlvDiagrammerTiledViewProxy.prototype.createObject=IlvDiagrammerViewProxyUtil.createObject;
IlvDiagrammerTiledViewProxy.capabilitiesLoaded=function(_21){
IlvDiagrammerViewProxyUtil.removeAdditionalParameters(_21);
};
IlvDiagrammerTiledViewProxy.imageLoaded=function(_22){
IlvDiagrammerViewProxyUtil.removeAdditionalParameters(_22);
};
IlvDiagrammerTiledViewProxy.prototype.setMakeObjectInteractor=IlvDiagrammerViewProxyUtil.setMakeObjectInteractor;
IlvDiagrammerMakeObjectInteractorProxy=function(_1){
this.superConstructor(_1);
this.setObject(new IlvMakeObjectInteractor());
};
IlvDiagrammerMakeObjectInteractorProxy.prototype=new IlvInteractorProxy();
IlvDiagrammerMakeObjectInteractorProxy.prototype.setClassName("IlvDiagrammerMakeObjectInteractorProxy");
IlvDiagrammerMakeObjectInteractorProxy.prototype.setLinkMode=function(_2){
this.getObject().setLinkMode(_2);
this.notify("LinkMode");
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.isLinkMode=function(_3){
return this.getObject().getLinkMode();
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.setAdditionalParameters=function(_4){
this.getObject().setAdditionalParameters(_4);
this.notify("AdditionalParameters");
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.getAdditionalParameters=function(){
return this.getObject().additionalParams;
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.setProperties=function(_5){
this.getObject().setProperties(_5);
this.notify("Properties");
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.getProperties=function(){
return this.getObject().properties;
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.setOneShot=function(_6){
this.oldInteractor=_6;
if(this.oldInteractor){
if(!this.popInteractorCallback){
this.popInteractorCallback=function(){
this.getView().JSFRef.setInteractor(this.JSFRef.oldInteractor);
};
}
this.getObject().setOnCompleted(this.popInteractorCallback);
}else{
this.oldInteractor=null;
this.getObject().setOnCompleted(null);
}
this.notify("OneShotId");
};
IlvDiagrammerMakeObjectInteractorProxy.prototype.getOneShotId=function(){
if(this.oldInteractor){
return this.oldInteractor.getAbsoluteId();
}else{
return null;
}
};
IlvDiagrammerSelectionManagerProxy=function(_1,_2,_3){
this.superConstructor(_1,_2.getSelectionManager(),_3);
};
IlvDiagrammerSelectionManagerProxy.prototype=new IlvFacesSelectionManagerProxy();
IlvDiagrammerSelectionManagerProxy.prototype.setClassName("IlvDiagrammerSelectionManagerProxy");
IlvFacesDiagrammerSelectInteractor=function(){
this.superConstructor();
};
IlvFacesDiagrammerSelectInteractor.prototype=new IlvSelectInteractor();
IlvFacesDiagrammerSelectInteractor.prototype.setClassName("IlvFacesDiagrammerSelectInteractor");
IlvFacesDiagrammerSelectInteractor.prototype.setView=function(_1){
if(_1==null){
this.JSFRef.desinstallInteractor(this.view.getSelectionManager());
}else{
this.JSFRef.setupSelectionManager(_1.getSelectionManager());
}
};
IlvFacesDiagrammerSelectInteractor.prototype.keyDown=function(e){
if(this.view!=null){
var _3=this.view.getSelectionManager();
if(e.keyCode==27){
if(_3!=null&&_3.isDragging()){
_3.abortDragging(e);
}
}else{
if(this.JSFRef.isDeletionAllowed()&&e.keyCode==46){
if(_3!=null&&!_3.isDragging()){
_3.deleteSelection();
}
}else{
if(e.keyCode==65&&e.ctrlKey){
var _3=this.view.getSelectionManager();
if(_3!=null){
_3.selectAll();
if(e.preventDefault){
e.preventDefault();
return false;
}
}
}
}
}
}
};
IlvDiagrammerSelectInteractorProxy=function(_4,_5){
this.superConstructor(_4,_5);
this.setObject(new IlvFacesDiagrammerSelectInteractor());
this.deletionAllowed=false;
};
IlvDiagrammerSelectInteractorProxy.prototype=new IlvFacesSelectInteractorProxy();
IlvDiagrammerSelectInteractorProxy.prototype.setClassName("IlvDiagrammerSelectInteractorProxy");
IlvDiagrammerSelectInteractorProxy.prototype.setDeletionAllowed=function(_6){
this.deletionAllowed=_6;
this.notify("DeletionAllowed");
};
IlvDiagrammerSelectInteractorProxy.prototype.isDeletionAllowed=function(){
return this.deletionAllowed;
};
}
